@@ -64,12 +64,17 @@ struct _PhotosApplication
 struct _PhotosApplicationClass
 {
   GtkApplicationClass parent_class;
+
+  /* signals */
+  void (*miners_changed) (PhotosApplication *self, GList *miners_running);
 };
 
 GType                  photos_application_get_type               (void) G_GNUC_CONST;
 
 GtkApplication        *photos_application_new                    (void);
 
+GList                 *photos_application_get_miners_running     (PhotosApplication *self);
+
 gint                   photos_application_get_scale_factor       (PhotosApplication *self);
 
 G_END_DECLS
