@@ -1,7 +1,7 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2014 Pranav Kant
- * Copyright © 2012, 2013, 2014 Red Hat, Inc.
+ * Copyright © 2014, 2015 Pranav Kant
+ * Copyright © 2012, 2013, 2014, 2015 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -41,6 +41,7 @@
 #include "photos-delete-item-job.h"
 #include "photos-filterable.h"
 #include "photos-icons.h"
+#include "photos-local-item.h"
 #include "photos-print-notification.h"
 #include "photos-print-operation.h"
 #include "photos-query.h"
@@ -207,7 +208,7 @@ photos_base_item_check_effects_and_update_info (PhotosBaseItem *self)
   GList *windows;
   GdkPixbuf *emblemed_pixbuf = NULL;
   GdkPixbuf *thumbnailed_pixbuf = NULL;
-  GdkWindow *window;
+  GdkWindow *window = NULL;
   gint scale;
 
   if (priv->original_icon == NULL)
@@ -293,7 +294,9 @@ photos_base_item_check_effects_and_update_info (PhotosBaseItem *self)
   app = g_application_get_default ();
   scale = photos_application_get_scale_factor (PHOTOS_APPLICATION (app));
   windows = gtk_application_get_windows (GTK_APPLICATION (app));
-  window = gtk_widget_get_window (GTK_WIDGET (windows->data));
+  if (windows != NULL)
+    window = gtk_widget_get_window (GTK_WIDGET (windows->data));
+
   priv->surface = gdk_cairo_surface_create_from_pixbuf (thumbnailed_pixbuf, scale, window);
 
   g_signal_emit (self, signals[INFO_UPDATED], 0);
@@ -347,6 +350,27 @@ photos_base_item_create_thumbnail_in_thread_func (gpointer data, gpointer user_d
 }
 
 
+static gint
+photos_base_item_create_thumbnail_sort_func (gconstpointer a, gconstpointer b, gpointer user_data)
+{
+  GTask *task_a = G_TASK (a);
+  GTask *task_b = G_TASK (b);
+  PhotosBaseItem *item_a;
+  PhotosBaseItem *item_b;
+  gint ret_val = 0;
+
+  item_a = PHOTOS_BASE_ITEM (g_task_get_source_object (task_a));
+  item_b = PHOTOS_BASE_ITEM (g_task_get_source_object (task_b));
+
+  if (PHOTOS_IS_LOCAL_ITEM (item_a))
+    ret_val = -1;
+  else if (PHOTOS_IS_LOCAL_ITEM (item_b))
+    ret_val = 1;
+
+  return ret_val;
+}
+
+
 static void
 photos_base_item_create_thumbnail_async (PhotosBaseItem *self,
                                          GCancellable *cancellable,
@@ -1094,7 +1118,9 @@ photos_base_item_class_init (PhotosBaseItemClass *class)
                                              1,
                                              FALSE,
                                              NULL);
-  g_assert (create_thumbnail_pool != NULL);
+  g_thread_pool_set_sort_function (create_thumbnail_pool,
+                                   (GCompareDataFunc) photos_base_item_create_thumbnail_sort_func,
+                                   NULL);
 }
 
 
