@@ -105,7 +105,7 @@ gchar              *photos_base_item_download_finish    (PhotosBaseItem *self, G
 
 const gchar        *photos_base_item_get_author         (PhotosBaseItem *self);
 
-GeglRectangle       photos_base_item_get_bbox           (PhotosBaseItem *self);
+void                photos_base_item_get_bbox           (PhotosBaseItem *self, GeglRectangle *out_bbox);
 
 gint64              photos_base_item_get_date_created   (PhotosBaseItem *self);
 
