@@ -25,6 +25,7 @@
 #ifndef PHOTOS_ITEM_MANAGER_H
 #define PHOTOS_ITEM_MANAGER_H
 
+#include <gegl.h>
 #include <gtk/gtk.h>
 #include <tracker-sparql.h>
 
@@ -68,11 +69,16 @@ struct _PhotosItemManager
 struct _PhotosItemManagerClass
 {
   PhotosBaseManagerClass parent_class;
+
+  /* signals */
+  void (*active_collection_changed) (PhotosItemManager *self, PhotosBaseItem *collection);
+  void (*load_finished)             (PhotosItemManager *self, PhotosBaseItem *item, GeglNode *node);
+  void (*load_started)              (PhotosItemManager *self, PhotosBaseItem *item, GCancellable *cancellable);
 };
 
 GType                     photos_item_manager_get_type           (void) G_GNUC_CONST;
 
-PhotosBaseManager        *photos_item_manager_dup_singleton      (void);
+PhotosBaseManager        *photos_item_manager_new                (void);
 
 void                      photos_item_manager_activate_previous_collection (PhotosItemManager *self);
 
@@ -82,6 +88,10 @@ void                      photos_item_manager_add_item           (PhotosItemMana
 PhotosBaseItem           *photos_item_manager_create_item        (PhotosItemManager *self,
                                                                   TrackerSparqlCursor *cursor);
 
+PhotosBaseItem           *photos_item_manager_get_active_collection (PhotosItemManager *self);
+
+GHashTable               *photos_item_manager_get_collections       (PhotosItemManager *self);
+
 G_END_DECLS
 
 #endif /* PHOTOS_ITEM_MANAGER_H */
