@@ -131,7 +131,7 @@ photos_main_toolbar_set_toolbar_title (PhotosMainToolbar *self)
 
       item = photos_base_manager_get_active_object (priv->item_mngr);
       if (item != NULL)
-        primary = g_markup_printf_escaped ("%s", photos_base_item_get_name (PHOTOS_BASE_ITEM (item)));
+        primary = g_markup_printf_escaped ("%s", photos_base_item_get_name_with_fallback (PHOTOS_BASE_ITEM (item)));
     }
 
   if (selection_mode)
