@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2013, 2014 Red Hat, Inc.
+ * Copyright © 2013, 2014, 2015 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -39,6 +39,7 @@
 
 struct _PhotosPreviewNavButtonsPrivate
 {
+  GtkGesture *tap_gesture;
   GtkTreeModel *model;
   GtkTreePath *current_path;
   GtkWidget *next_widget;
@@ -49,8 +50,8 @@ struct _PhotosPreviewNavButtonsPrivate
   PhotosPreviewAction action;
   gboolean enable_next;
   gboolean enable_prev;
-  gboolean hover;
   gboolean visible;
+  gboolean visible_internal;
   guint auto_hide_id;
   guint motion_id;
 };
@@ -58,8 +59,6 @@ struct _PhotosPreviewNavButtonsPrivate
 enum
 {
   PROP_0,
-  PROP_ENABLE_NEXT,
-  PROP_ENABLE_PREVIOUS,
   PROP_OVERLAY,
   PROP_PREVIEW_VIEW
 };
@@ -114,14 +113,50 @@ photos_preview_nav_buttons_fade_out_button (PhotosPreviewNavButtons *self, GtkWi
 }
 
 
+static void
+photos_preview_nav_buttons_update_visibility (PhotosPreviewNavButtons *self)
+{
+  PhotosPreviewNavButtonsPrivate *priv = self->priv;
+  GtkTreeIter iter;
+  GtkTreeIter tmp;
+
+  if (priv->model == NULL
+      || priv->current_path == NULL
+      || !priv->visible
+      || !gtk_tree_model_get_iter (priv->model, &iter, priv->current_path))
+    {
+      priv->enable_prev = FALSE;
+      priv->enable_next = FALSE;
+      goto out;
+    }
+
+  tmp = iter;
+  priv->enable_prev = gtk_tree_model_iter_previous (priv->model, &tmp);
+
+  tmp = iter;
+  priv->enable_next = gtk_tree_model_iter_next (priv->model, &tmp);
+
+ out:
+  if (priv->visible_internal && priv->enable_next)
+    photos_preview_nav_buttons_fade_in_button (self, priv->next_widget);
+  else
+    photos_preview_nav_buttons_fade_out_button (self, priv->next_widget);
+
+  if (priv->visible_internal && priv->enable_prev)
+    photos_preview_nav_buttons_fade_in_button (self, priv->prev_widget);
+  else
+    photos_preview_nav_buttons_fade_out_button (self, priv->prev_widget);
+}
+
+
 static gboolean
 photos_preview_nav_buttons_auto_hide (PhotosPreviewNavButtons *self)
 {
   PhotosPreviewNavButtonsPrivate *priv = self->priv;
 
-  photos_preview_nav_buttons_fade_out_button (self, priv->prev_widget);
-  photos_preview_nav_buttons_fade_out_button (self, priv->next_widget);
   priv->auto_hide_id = 0;
+  priv->visible_internal = FALSE;
+  photos_preview_nav_buttons_update_visibility (self);
   return G_SOURCE_REMOVE;
 }
 
@@ -142,7 +177,6 @@ photos_preview_nav_buttons_unqueue_auto_hide (PhotosPreviewNavButtons *self)
 static gboolean
 photos_preview_nav_buttons_enter_notify (PhotosPreviewNavButtons *self)
 {
-  self->priv->hover = TRUE;
   photos_preview_nav_buttons_unqueue_auto_hide (self);
   return FALSE;
 }
@@ -165,62 +199,39 @@ photos_preview_nav_buttons_queue_auto_hide (PhotosPreviewNavButtons *self)
 static gboolean
 photos_preview_nav_buttons_leave_notify (PhotosPreviewNavButtons *self)
 {
-  self->priv->hover = FALSE;
   photos_preview_nav_buttons_queue_auto_hide (self);
   return FALSE;
 }
 
 
-static void
-photos_preview_nav_buttons_update_visibility (PhotosPreviewNavButtons *self)
-{
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
-  GtkTreeIter iter;
-  GtkTreeIter tmp;
-  gboolean enable_next = FALSE;
-  gboolean enable_prev = FALSE;
-
-  if (priv->model == NULL
-      || priv->current_path == NULL
-      || !priv->visible
-      || !gtk_tree_model_get_iter (priv->model, &iter, priv->current_path))
-    {
-      enable_prev = FALSE;
-      enable_next = FALSE;
-      goto out;
-    }
-
-  tmp = iter;
-  enable_prev = gtk_tree_model_iter_previous (priv->model, &tmp);
-
-  tmp = iter;
-  enable_next = gtk_tree_model_iter_next (priv->model, &tmp);
-
-  if (!priv->hover)
-    photos_preview_nav_buttons_queue_auto_hide (self);
-
- out:
-  g_object_set (self, "enable-next", enable_next, "enable-previous", enable_prev, NULL);
-}
-
-
 static gboolean
 photos_preview_nav_buttons_motion_notify_timeout (PhotosPreviewNavButtons *self)
 {
-  self->priv->motion_id = 0;
+  PhotosPreviewNavButtonsPrivate *priv = self->priv;
+
+  priv->motion_id = 0;
+  priv->visible_internal = TRUE;
   photos_preview_nav_buttons_update_visibility (self);
+  photos_preview_nav_buttons_queue_auto_hide (self);
   return G_SOURCE_REMOVE;
 }
 
 
 static gboolean
-photos_preview_nav_buttons_motion_notify (PhotosPreviewNavButtons *self)
+photos_preview_nav_buttons_motion_notify (PhotosPreviewNavButtons *self, GdkEventMotion *event)
 {
   PhotosPreviewNavButtonsPrivate *priv = self->priv;
+  GdkDevice *device;
+  GdkInputSource input_source;
 
   if (priv->motion_id != 0)
     return FALSE;
 
+  device = gdk_event_get_source_device ((GdkEvent *) event);
+  input_source = gdk_device_get_source (device);
+  if (input_source == GDK_SOURCE_TOUCHSCREEN)
+    return FALSE;
+
   priv->motion_id = g_idle_add_full (G_PRIORITY_DEFAULT,
                                      (GSourceFunc) photos_preview_nav_buttons_motion_notify_timeout,
                                      g_object_ref (self),
@@ -230,26 +241,21 @@ photos_preview_nav_buttons_motion_notify (PhotosPreviewNavButtons *self)
 
 
 static void
-photos_preview_nav_buttons_notify_enable_next (PhotosPreviewNavButtons *self)
+photos_preview_nav_buttons_multi_press_released (PhotosPreviewNavButtons *self)
 {
   PhotosPreviewNavButtonsPrivate *priv = self->priv;
 
-  if (priv->enable_next)
-    photos_preview_nav_buttons_fade_in_button (self, priv->next_widget);
-  else
-    photos_preview_nav_buttons_fade_out_button (self, priv->next_widget);
+  gtk_gesture_set_state (GTK_GESTURE (priv->tap_gesture), GTK_EVENT_SEQUENCE_CLAIMED);
+  priv->visible_internal = !priv->visible_internal;
+  photos_preview_nav_buttons_unqueue_auto_hide (self);
+  photos_preview_nav_buttons_update_visibility (self);
 }
 
 
 static void
-photos_preview_nav_buttons_notify_enable_previous (PhotosPreviewNavButtons *self)
+photos_preview_nav_buttons_multi_press_stopped (PhotosPreviewNavButtons *self)
 {
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
-
-  if (priv->enable_prev)
-    photos_preview_nav_buttons_fade_in_button (self, priv->prev_widget);
-  else
-    photos_preview_nav_buttons_fade_out_button (self, priv->prev_widget);
+  gtk_gesture_set_state (GTK_GESTURE (self->priv->tap_gesture), GTK_EVENT_SEQUENCE_DENIED);
 }
 
 
@@ -283,6 +289,7 @@ photos_preview_nav_buttons_dispose (GObject *object)
   PhotosPreviewNavButtons *self = PHOTOS_PREVIEW_NAV_BUTTONS (object);
   PhotosPreviewNavButtonsPrivate *priv = self->priv;
 
+  g_clear_object (&priv->tap_gesture);
   g_clear_object (&priv->model);
   g_clear_object (&priv->overlay);
   g_clear_object (&priv->preview_view);
@@ -377,29 +384,17 @@ photos_preview_nav_buttons_constructed (GObject *object)
                             "motion-notify-event",
                             G_CALLBACK (photos_preview_nav_buttons_motion_notify),
                             self);
-}
 
-
-static void
-photos_preview_nav_buttons_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
-{
-  PhotosPreviewNavButtons *self = PHOTOS_PREVIEW_NAV_BUTTONS (object);
-  PhotosPreviewNavButtonsPrivate *priv = self->priv;
-
-  switch (prop_id)
-    {
-    case PROP_ENABLE_NEXT:
-      g_value_set_boolean (value, priv->enable_next);
-      break;
-
-    case PROP_ENABLE_PREVIOUS:
-      g_value_set_boolean (value, priv->enable_prev);
-      break;
-
-    default:
-      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-      break;
-    }
+  priv->tap_gesture = gtk_gesture_multi_press_new (priv->preview_view);
+  gtk_gesture_single_set_touch_only (GTK_GESTURE_SINGLE (priv->tap_gesture), TRUE);
+  g_signal_connect_swapped (priv->tap_gesture,
+                            "released",
+                            G_CALLBACK (photos_preview_nav_buttons_multi_press_released),
+                            self);
+  g_signal_connect_swapped (priv->tap_gesture,
+                            "stopped",
+                            G_CALLBACK (photos_preview_nav_buttons_multi_press_stopped),
+                            self);
 }
 
 
@@ -411,14 +406,6 @@ photos_preview_nav_buttons_set_property (GObject *object, guint prop_id, const G
 
   switch (prop_id)
     {
-    case PROP_ENABLE_NEXT:
-      priv->enable_next = g_value_get_boolean (value);
-      break;
-
-    case PROP_ENABLE_PREVIOUS:
-      priv->enable_prev = g_value_get_boolean (value);
-      break;
-
     case PROP_OVERLAY:
       priv->overlay = GTK_WIDGET (g_value_dup_object (value));
       break;
@@ -450,15 +437,6 @@ photos_preview_nav_buttons_init (PhotosPreviewNavButtons *self)
   priv->item_mngr = g_object_ref (state->item_mngr);
 
   priv->action = PHOTOS_PREVIEW_ACTION_NONE;
-
-  g_signal_connect (self,
-                    "notify::enable-next",
-                    G_CALLBACK (photos_preview_nav_buttons_notify_enable_next),
-                    NULL);
-  g_signal_connect (self,
-                    "notify::enable-previous",
-                    G_CALLBACK (photos_preview_nav_buttons_notify_enable_previous),
-                    NULL);
 }
 
 
@@ -470,25 +448,8 @@ photos_preview_nav_buttons_class_init (PhotosPreviewNavButtonsClass *class)
   object_class->constructed = photos_preview_nav_buttons_constructed;
   object_class->dispose = photos_preview_nav_buttons_dispose;
   object_class->finalize = photos_preview_nav_buttons_finalize;
-  object_class->get_property = photos_preview_nav_buttons_get_property;
   object_class->set_property = photos_preview_nav_buttons_set_property;
 
-  g_object_class_install_property (object_class,
-                                   PROP_ENABLE_NEXT,
-                                   g_param_spec_boolean ("enable-next",
-                                                         "Enable next",
-                                                         "Allow moving to the next item",
-                                                         FALSE,
-                                                         G_PARAM_READWRITE));
-
-  g_object_class_install_property (object_class,
-                                   PROP_ENABLE_PREVIOUS,
-                                   g_param_spec_boolean ("enable-previous",
-                                                         "Enable previous",
-                                                         "Allow moving to the previous item",
-                                                         FALSE,
-                                                         G_PARAM_READWRITE));
-
   g_object_class_install_property (object_class,
                                    PROP_OVERLAY,
                                    g_param_spec_object ("overlay",
@@ -539,8 +500,8 @@ photos_preview_nav_buttons_hide (PhotosPreviewNavButtons *self)
 
   priv->action = PHOTOS_PREVIEW_ACTION_NONE;
   priv->visible = FALSE;
-  photos_preview_nav_buttons_fade_out_button (self, priv->prev_widget);
-  photos_preview_nav_buttons_fade_out_button (self, priv->next_widget);
+  priv->visible_internal = FALSE;
+  photos_preview_nav_buttons_update_visibility (self);
 
   g_signal_emit (self, signals[ACTIVATED], 0, priv->action);
 }
@@ -557,6 +518,7 @@ photos_preview_nav_buttons_next (PhotosPreviewNavButtons *self)
   priv->action = PHOTOS_PREVIEW_ACTION_NEXT;
   gtk_tree_path_next (priv->current_path);
   photos_preview_nav_buttons_set_active_path (self);
+  photos_preview_nav_buttons_update_visibility (self);
 
   g_signal_emit (self, signals[ACTIVATED], 0, priv->action);
 }
@@ -573,6 +535,7 @@ photos_preview_nav_buttons_previous (PhotosPreviewNavButtons *self)
   priv->action = PHOTOS_PREVIEW_ACTION_PREVIOUS;
   gtk_tree_path_prev (priv->current_path);
   photos_preview_nav_buttons_set_active_path (self);
+  photos_preview_nav_buttons_update_visibility (self);
 
   g_signal_emit (self, signals[ACTIVATED], 0, priv->action);
 }
@@ -593,8 +556,6 @@ photos_preview_nav_buttons_set_model (PhotosPreviewNavButtons *self, GtkTreeMode
       priv->current_path = gtk_tree_model_filter_convert_child_path_to_path (GTK_TREE_MODEL_FILTER (priv->model),
                                                                              current_path);
     }
-
-  photos_preview_nav_buttons_update_visibility (self);
 }
 
 
@@ -605,7 +566,9 @@ photos_preview_nav_buttons_show (PhotosPreviewNavButtons *self)
 
   priv->action = PHOTOS_PREVIEW_ACTION_NONE;
   priv->visible = TRUE;
+  priv->visible_internal = TRUE;
   photos_preview_nav_buttons_update_visibility (self);
+  photos_preview_nav_buttons_queue_auto_hide (self);
 
   g_signal_emit (self, signals[ACTIVATED], 0, priv->action);
 }
